@@ -10,15 +10,15 @@
 
 #include "kwidgetlister.h"
 
-#include <KLocalizedString>
 #include <KGuiItem>
+#include <KLocalizedString>
 #include <QHBoxLayout>
 
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <assert.h>
 #include <KStandardGuiItem>
+#include <assert.h>
 
 using namespace KPIM;
 
@@ -84,24 +84,22 @@ void KWidgetLister::init(bool fewerMoreButton)
     d->mLayout->setSpacing(4);
 
     d->mButtonBox = new QWidget(this);
-    auto *mButtonBoxHBoxLayout = new QHBoxLayout(d->mButtonBox);
+    auto mButtonBoxHBoxLayout = new QHBoxLayout(d->mButtonBox);
     mButtonBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mLayout->addWidget(d->mButtonBox);
 
     if (fewerMoreButton) {
         d->mBtnMore = new QPushButton(d->mButtonBox);
         mButtonBoxHBoxLayout->addWidget(d->mBtnMore);
-        KGuiItem::assign(d->mBtnMore, KGuiItem(i18nc("more widgets", "More"),
-                                               QStringLiteral("list-add")));
+        KGuiItem::assign(d->mBtnMore, KGuiItem(i18nc("more widgets", "More"), QStringLiteral("list-add")));
         mButtonBoxHBoxLayout->setStretchFactor(d->mBtnMore, 0);
 
         d->mBtnFewer = new QPushButton(d->mButtonBox);
         mButtonBoxHBoxLayout->addWidget(d->mBtnFewer);
-        KGuiItem::assign(d->mBtnFewer, KGuiItem(i18nc("fewer widgets", "Fewer"),
-                                                QStringLiteral("list-remove")));
+        KGuiItem::assign(d->mBtnFewer, KGuiItem(i18nc("fewer widgets", "Fewer"), QStringLiteral("list-remove")));
         mButtonBoxHBoxLayout->setStretchFactor(d->mBtnFewer, 0);
     }
-    QWidget *spacer = new QWidget(d->mButtonBox);
+    auto spacer = new QWidget(d->mButtonBox);
     mButtonBoxHBoxLayout->addWidget(spacer);
     mButtonBoxHBoxLayout->setStretchFactor(spacer, 1);
 
@@ -185,7 +183,7 @@ void KWidgetLister::removeLastWidget()
 
 void KWidgetLister::clearWidget(QWidget *widget)
 {
-    Q_UNUSED(widget);
+    Q_UNUSED(widget)
 }
 
 QWidget *KWidgetLister::createWidget(QWidget *parent)
