@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ public:
         : labelStr(_label)
         , q(qq)
     {
-        auto *lay = new QHBoxLayout(q);
+        auto lay = new QHBoxLayout(q);
         lay->setContentsMargins(0, 0, 0, 0);
         indicator = new KBusyIndicatorWidget;
         lay->addWidget(indicator);
